@@ -4,7 +4,7 @@
  *
  * Implementation of the simple NearestNeighborSort policy class.
  *
- * This file is part of MLPACK 1.0.9.
+ * This file is part of MLPACK 1.0.10.
  *
  * MLPACK is free software: you can redistribute it and/or modify it under the
  * terms of the GNU Lesser General Public License as published by the Free
@@ -23,20 +23,20 @@
 
 using namespace mlpack::neighbor;
 
-long NearestNeighborSort::SortDistance(const arma::vec& list,
-                                         const arma::Col<long>& indices,
+size_t NearestNeighborSort::SortDistance(const arma::vec& list,
+                                         const arma::Col<size_t>& indices,
                                          double newDistance)
 {
   // The first element in the list is the nearest neighbor.  We only want to
   // insert if the new distance is less than the last element in the list.
   if (newDistance > list[list.n_elem - 1])
-    return (long() - 1); // Do not insert.
+    return (size_t() - 1); // Do not insert.
 
   // Search from the beginning.  This may not be the best way.
-  for (long i = 0; i < list.n_elem; i++)
-    if (newDistance <= list[i] || indices[i] == (long() - 1))
+  for (size_t i = 0; i < list.n_elem; i++)
+    if (newDistance <= list[i] || indices[i] == (size_t() - 1))
       return i;
 
   // Control should never reach here.
-  return (long() - 1);
+  return (size_t() - 1);
 }
